@@ -9,16 +9,16 @@
 #'  \code{\link[rcongresso]{fetch_votos}}
 #' @rdname fetch_votacao
 #' @export
-fetch_votacao <- function(id_votacao){
-  id <- NULL
-  tibble::tibble(id = id_votacao) %>%
-    dplyr::mutate(path = paste0(.VOTACOES_PATH, "/", id)) %>%
+fetch_votacao <- function(id_votacao = NULL){
+  tibble::tibble(id_votacao) %>%
+    dplyr::mutate(path = paste0(.VOTACOES_PATH, "/", id_votacao)) %>%
     dplyr::rowwise() %>%
     dplyr::do(
-      .congresso_api(.$path)$dados %>%
-        .remove_lists_and_nulls()
+      .congresso_api(.$path)
     ) %>%
-    dplyr::ungroup()
+    dplyr::select(-which(grepl("orientacoes", names(.)))) %>%
+    .assert_dataframe_completo(.COLNAMES_VOTACAO) %>%
+    .coerce_types(.COLNAMES_VOTACAO)
 }
 
 #' @title Fetches the positions of a group on a voting
@@ -32,17 +32,16 @@ fetch_votacao <- function(id_votacao){
 #'  \code{\link[rcongresso]{get_votos_partidos}}
 #' @rdname fetch_orientacoes
 #' @export
-fetch_orientacoes <- function(id_votacao){
-  id <- NULL
-  tibble::tibble(id = id_votacao) %>%
-    dplyr::mutate(path = paste0(.VOTACOES_PATH, "/", id)) %>%
-    dplyr::group_by(id) %>%
+fetch_orientacoes <- function(id_votacao = NULL){
+  tibble::tibble(id_votacao) %>%
+    dplyr::mutate(path = paste0(.VOTACOES_PATH, "/", id_votacao)) %>%
+    dplyr::group_by(id_votacao) %>%
     dplyr::do(
-      .congresso_api(.$path)$dados$orientacoes
+      .congresso_api(.$path, asList = TRUE)$orientacoes
     ) %>%
     dplyr::ungroup() %>%
-    dplyr::mutate(id_votacao = id) %>%
-    dplyr::select(-id)
+    .assert_dataframe_completo(.COLNAMES_ORIENTACOES) %>%
+    .coerce_types(.COLNAMES_ORIENTACOES)
 }
 
 #' @title Fetches individual votes from a voting
@@ -56,9 +55,9 @@ fetch_orientacoes <- function(id_votacao){
 #'  \code{\link[rcongresso]{fetch_votacao}}
 #' @rdname fetch_votos
 #' @export
-fetch_votos <- function(id_votacao){
+fetch_votos <- function(id_votacao = NULL){
   path <- query <- NULL
-  queries <- tibble::tibble(id_votacao = id_votacao) %>%
+  queries <- tibble::tibble(id_votacao) %>%
     dplyr::mutate(path = paste0(.VOTACOES_PATH, "/", id_votacao, "/votos")) %>%
     dplyr::rowwise() %>%
     dplyr::do(
@@ -71,11 +70,12 @@ fetch_votos <- function(id_votacao){
   queries %>%
     dplyr::group_by(id_votacao, path, query) %>%
     dplyr::do(
-      .congresso_api(.$path, .$query)$dados %>%
-        .empty_list_to_dataframe()
+      .congresso_api(.$path, .$query)
     ) %>%
     dplyr::ungroup() %>%
-    dplyr::select(-path, -query)
+    dplyr::select(-path, -query) %>%
+    .assert_dataframe_completo(.COLNAMES_VOTOS) %>%
+    .coerce_types(.COLNAMES_VOTOS)
 }
 
 #' @title Gets the last voting on a given voting
@@ -87,7 +87,7 @@ fetch_votos <- function(id_votacao){
 #' ultima_votacao <- ultima_votacao(votacoes_pec241)
 #' @rdname ultima_votacao
 #' @export
-ultima_votacao <- function(votacoes) {
+ultima_votacao <- function(votacoes = NULL) {
   uriProposicaoPrincipal <- id <- NULL
 
   votacoes %>%
@@ -95,7 +95,9 @@ ultima_votacao <- function(votacoes) {
     dplyr::filter(id == max(id)) %>%
     unique() %>%
     dplyr::ungroup() %>%
-    dplyr::select(id, uriProposicaoPrincipal)
+    dplyr::select(id, uriProposicaoPrincipal) %>%
+    .assert_dataframe_completo(.COLNAMES_ULTIMAVOTACAO) %>%
+    .coerce_types(.COLNAMES_ULTIMAVOTACAO)
 }
 
 #' @title Fetches the positions by party on a voting
@@ -109,7 +111,7 @@ ultima_votacao <- function(votacoes) {
 #'  \code{\link[rcongresso]{fetch_orientacoes}}
 #' @rdname get_votos_partidos
 #' @export
-get_votos_partidos <- function(votacao) {
+get_votos_partidos <- function(votacao = NULL) {
   nomeBancada <- voto <- bancada_associada <- id_votacao <- partido <- NULL
 
   fetch_orientacoes(votacao) %>%
@@ -117,7 +119,9 @@ get_votos_partidos <- function(votacao) {
     dplyr::select(partido = nomeBancada, orientacao_partido = voto,
                   bancada_associada, id_votacao) %>%
     tidyr::separate_rows(partido, sep = .REGEX_PATTERN) %>%
-    dplyr::mutate(partido = toupper(.$partido))
+    dplyr::mutate(partido = toupper(.$partido)) %>%
+    .assert_dataframe_completo(.COLNAMES_VOTOSPARTIDOS) %>%
+    .coerce_types(.COLNAMES_VOTOSPARTIDOS)
 }
 
 #' @title Finds the id of the proposition to which a given voting refers
@@ -128,17 +132,17 @@ get_votos_partidos <- function(votacao) {
 #' pec241 <- fetch_proposicao_from_votacao(7252)
 #' @rdname fetch_proposicao_from_votacao
 #' @export
-fetch_proposicao_from_votacao <- function(id_votacao) {
+fetch_proposicao_from_votacao <- function(id_votacao = NULL) {
   id <- NULL
-
   tibble::tibble(id_votacao) %>%
     dplyr::mutate(path = paste0(.VOTACOES_PATH, "/", id_votacao)) %>%
     dplyr::group_by(id_votacao) %>%
     dplyr::do(
-      .congresso_api(.$path)$dados$proposicao %>%
-        .remove_lists_and_nulls()
+      .congresso_api(.$path, asList = TRUE)$proposicao %>%
+        .get_dataframe()
     ) %>%
     dplyr::ungroup() %>%
-    dplyr::mutate(id_proposicao = id) %>%
-    dplyr::select(-id)
+    dplyr::rename(id_proposicao = id) %>%
+    .assert_dataframe_completo(.COLNAMES_PROP_VOTACAO) %>%
+    .coerce_types(.COLNAMES_PROP_VOTACAO)
 }
